@@ -2,8 +2,7 @@ package Growl::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.4'; # VERSION
-
+our $VERSION = '0.0.5'; # VERSION
 use base 'Exporter';
 our @EXPORT_OK = ( 'notify' );
 
@@ -18,7 +17,7 @@ Growl::Tiny - tiny perl module for sending Growl notifications on Mac OS X
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -91,8 +90,8 @@ Optional priority.  This can be -2, -1, 0, 1, or 2.
 
 =item sticky
 
-If 'sticky' is set to 'true', then the notification will remain
-on-screen until clicked.
+If 'sticky' is true, then the notification will remain on-screen until
+clicked.
 
 =item quiet
 
@@ -125,8 +124,12 @@ options for your application in the growl preferences pane under the
 =item identifier
 
 Sets the identifier for the notification. The identifier is used for
-coalescing, which means multiple notifications with the same identifer
-will use a single bubble, the latest notification taking precedence.
+coalescing, which means that an old notifications with the same
+identifier will be replaced with the new notification.
+
+=item url
+
+Notification click will result in the URL being opened.
 
 =back
 
@@ -163,6 +166,10 @@ sub notify {
         push @command_line_args, ( '-p', $options->{priority} );
     }
 
+    if ( $options->{url} ) {
+        push @command_line_args, ( '--url', $options->{url} );
+    }
+
     my $host = $options->{host} || $ENV{GROWL_HOST};
     if ( $host ) {
         push @command_line_args, ( '-H', $host );
